#!/bin/bash

# Usage: ./generate-html.sh [<gs-major-version-number]
# The optional parameter major version number, which can be 2 or 3, will be assumed to be (Greenstone) "2" if none is provided
if [ "$GSDLHOME" == "" ]; then
    echo "You must run 'source setup.bash' in the top level folder of your Greenstone installation before running this script"
    echo "Usage: $0 [gs-major-version-number=2]"
    exit
fi

#ApplyXSLT.java will take care of setting the default of the major Greenstone version if none is provided
#if [ "$1" != "" ]; then
#    $major_version="2"
#fi

top_dir=`pwd`
shared_dir=`pwd`/../shared
source_dir=`pwd`/xml-source
processing_dir=`pwd`/processing
output_dir=`pwd`/html

export CLASSPATH=$shared_dir:$GSDLHOME/gli:$GSDLHOME/gli/classes:$GSDLHOME/perllib:$shared_dir/xalan.jar

if [ ! -d $output_dir ]; then
    mkdir $output_dir
fi

langs="en fr es ru"

# http://tadek.pietraszek.org/blog/2006/01/05/messing-up-with-command-line-arguments-in-bash/
# is on the difference between $@ and $* and when to add quotes around them

echo "processing top level index"
java -DGSDLHOME=$GSDLHOME ApplyXSLT "en" $processing_dir/xml-to-top-index.xsl  $source_dir/tutorial_en.xml "$@" > $output_dir/index.html

echo "generating wiki index page"
java -DGSDLHOME=$GSDLHOME ApplyXSLT "en" $processing_dir/xml-to-wiki-index.xsl $source_dir/tutorial_en.xml "$@" > $output_dir/wiki-index.txt

for l in $langs; do
    echo "Processing $l version"
    if [ ! -d $output_dir/$l ]; then
	mkdir $output_dir/$l
    fi
    cd $output_dir/$l
    java -DGSDLHOME=$GSDLHOME ApplyXSLT $l $processing_dir/xml-to-index.xsl $source_dir/tutorial_$l.xml "$@" > index.html
    java -DGSDLHOME=$GSDLHOME ApplyXSLT $l $processing_dir/xml-to-one-html.xsl $source_dir/tutorial_$l.xml "$@" > all_tutorials.html
    java -DGSDLHOME=$GSDLHOME ApplyXSLT $l $processing_dir/xml-to-many-html.xsl $source_dir/tutorial_$l.xml "$@" | perl -S $GSDLHOME/gli/help/splithelpdocument.pl
    cd $top_dir
done



